@@ -1,4 +1,4 @@
-#pip install -U sentence-transformers
+#pip install -U sentence-transformers   | uvicorn sntvec:app --host 0.0.0.0 --port 19200 --reload
 import fire ,json, requests
 from sentence_transformers import SentenceTransformer
 model = SentenceTransformer('all-MiniLM-L6-v2')
@@ -77,7 +77,6 @@ config = {
 			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
-			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"i": { "type": "integer"},
 			"score": { "type": "float"},
 			"offset": { "type": "float"},
@@ -176,6 +175,19 @@ config = {
 			"n": { "type": "keyword",  "index": "false"},
 			"adj": { "type": "keyword",  "index": "false"},
 			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"},
+			"ske": { "type": "text", "analyzer": "standard"},
+			"sntvec": {
+				   "type": "dense_vector",
+				   "dims": 384, 
+				   "index": "true",
+				   "similarity": "l2_norm"
+				 },
+			"skevec": {
+				   "type": "dense_vector",
+				   "dims": 384, 
+				   "index": "true",
+				   "similarity": "l2_norm"
+				 },
 			"vec": {
 				   "type": "dense_vector",
 				   "dims": 384, # use sbert 
@@ -186,10 +198,9 @@ config = {
 		}
 	}
 
-#es = Elasticsearch(['es.wrask.com:9200'], http_auth=('elastic', 'cikuutest!'), timeout=3600)
 from elasticsearch import Elasticsearch,helpers
 es = Elasticsearch(  
-    "https://localhost:9200",
+    "https://localhost:9200", 
     ca_certs="/home/ubuntu/http_ca.crt",
 	http_auth=('elastic', 'cikuutest!'), timeout=3600 )
 
@@ -198,10 +209,9 @@ app.title = "snt vec search"
 app.tm = "2022.2.18"
 
 @app.get('/sntvec/snt')
-def snt_search(snt:str="I'm glad to meet you.", index:str='gzjc', topk:int=10): 
+def snt_search(snt:str="I'm glad to meet you.", index:str='testidx', topk:int=10): 
 	''' search sent with nearest semantic '''
 	vec = model.encode(snt.strip())
-	#res = es.search(index=index, body={})
 	res = es.knn_search(index=index, source=['snt'],knn={ 
 	"field": "vec",
    "query_vector": vec,
@@ -209,6 +219,23 @@ def snt_search(snt:str="I'm glad to meet you.", index:str='gzjc', topk:int=10):
    "num_candidates": topk})
 	return res
 
+@app.get('/sntvec/query')
+def sntvec_query(query:str="I'm glad to meet you.", index:str='testidx', field:str='sntvec', topk:int=10): 
+	''' field: sntvec/skevec , added 2022.3.21 '''
+	vec = model.encode(query.strip())
+	res = es.knn_search(index=index, source=['snt','ske'], knn={ 
+	"field": field,
+   "query_vector": vec,
+   "k": 10,
+   "num_candidates": topk})
+	return res
+
+@app.get('/sntvec/newindex')
+def newindex(idxname:str='testidx'):  
+	''' '''
+	if es.indices.exists(index = idxname): es.indices.delete(index = idxname) 
+	return es.indices.create(index=idxname, body=config)
+
 @app.get('/sntvec/tovec')
 def snt_tovec(snt:str="I'm glad to meet you."): 
 	''' search sent with nearest semantic '''
@@ -221,16 +248,23 @@ def index_list():
 	return es.sql.query(query = "show tables").get('rows',[])
 
 @app.get('/sntvec/delete_by_id')
-def delete_by_id(index:str='gzjc', id:str='xxx'): 
+def delete_by_id(index:str='testidx', id:str='xxx'): 
 	''' delete_by_id '''
 	return es.delete(index=index, id=id)
 
 @app.get('/sntvec/add_new_snt')
-def add_new_snt(index:str='gzjc', snt:str='Justice delayed is justice denied.'): 
+def add_new_snt(index:str='testidx', snt:str='Justice delayed is justice denied.'): 
 	'''  '''
 	vec = model.encode(snt.strip())
 	return es.index(index=index, document={"snt":snt, "vec": vec.tolist()})
 
+@app.get('/sntvec/add_new_snt_with_ske')
+def add_new_snt(index:str='testidx', snt:str='Justice delayed is justice denied.', ske:str="_NP delayed is _NP denied ."): 
+	'''  '''
+	sntvec = model.encode(snt.strip())
+	skevec = model.encode(ske.strip())
+	return es.index(index=index, document={"snt":snt, "ske":ske,  "sntvec": sntvec.tolist(), "skevec": skevec.tolist()})
+
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
 		while True:
